.. tricircle documentation master file, created by
   sphinx-quickstart on Wed Dec 2 17:00:36 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tricircle's documentation!
========================================================

Contents:

.. toctree::
   :maxdepth: 2

   api_v1

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
